==> rivet-3.1.10.tar.gz: Rivet-3.1.10/pyext/rivet/hepdatapatches/__init__.py <==
from . import ALEPH_1991_S2435284
from . import ALEPH_1996_I402895
from . import ALEPH_1996_S3486095
from . import AMY_1990_I283337
from . import AMY_1990_I295160
from . import AMY_1995_I406129
from . import ARGUS_1988_I251097
from . import ARGUS_1989_I262551
from . import ARGUS_1989_I268577
from . import ARGUS_1989_I278932
from . import ARGUS_1989_I280943
from . import ARGUS_1989_I282570
from . import ARGUS_1990_I278933
from . import ARGUS_1991_I315059
from . import ARGUS_1992_I319102
from . import ARGUS_1993_S2653028
from . import ARGUS_1993_S2789213
from . import ARGUS_1994_I354224
from . import ATLAS_2013_I1190187
from . import ATLAS_2016_I1468168
from . import ATLAS_2018_I1615866
from . import ATLAS_2018_I1635273
from . import ATLAS_2018_I1711223
from . import ATLAS_2019_I1720438
from . import ATLAS_2019_I1734263
from . import ATLAS_2019_I1746286
from . import ATLAS_2020_I1790439
from . import ATLAS_2022_I2037744
from . import ATLAS_2022_I2077570
from . import ATLAS_2022_I2614196
from . import ATLAS_2023_I2648096
from . import BABAR_2001_I558091
from . import BABAR_2005_S6181155
from . import BABAR_2006_I731865
from . import BABAR_2007_S6895344
from . import BABAR_2016_I1391152
from . import BELLE_2001_S4598261
from . import BELLE_2007_I749358
from . import BELLE_2009_I823878
from . import BELLE_2016_I1389855
from . import BESIII_2015_I1391138
from . import BESII_2004_I622224
from . import CELLO_1982_I12010
from . import CELLO_1983_I191415
from . import CELLO_1990_I283026
from . import CELLO_1992_I345437
from . import CLEO_1985_I205668
from . import CLEO_1984_I193577
from . import CLEO_1998_I445351
from . import CLEO_2000_I526554
from . import CLEO_2001_I552541
from . import CLEO_2004_S5809304
from . import CLEOII_1999_I504672
from . import CLEOII_1999_I478217
from . import CMD3_2016_I1385598
from . import CMS_2016_I1487288
from . import CMS_2017_I1608166
from . import CMS_2017_I1631985
from . import CRYSTAL_BALL_1988_I261078
from . import CRYSTAL_BALL_1989_I263581
from . import CRYSTAL_BALL_1991_I297905
from . import DELPHI_1990_I297698
from . import DELPHI_1991_I301657
from . import DELPHI_1991_I324035
from . import DELPHI_1992_I334948
from . import DELPHI_1993_I356732
from . import DELPHI_1993_I360638
from . import DELPHI_1995_I377487
from . import DELPHI_1995_I382285
from . import DELPHI_1995_I394052
from . import DELPHI_1995_S3137023
from . import DELPHI_1996_S3430090
from . import DELPHI_1998_I473409
from . import DELPHI_1999_I448370
from . import DELPHI_2001_I526164
from . import DELPHI_2003_I620250
from . import DELPHI_2011_I890503
from . import DM1_1979_I132828
from . import DM2_1990_I297706
from . import E605_1991_I302822
from . import HRS_1985_I201482
from . import HRS_1986_I17781
from . import HRS_1986_I18688
from . import HRS_1986_I18502
from . import HRS_1987_I215848
from . import HRS_1988_I250824
from . import HRS_1989_I276948
from . import HRS_1990_I280958
from . import HRS_1992_I339573
from . import JADE_1984_I202785
from . import JADE_1985_I213948
from . import JADE_1990_I282847
from . import L3_1990_I298078
from . import L3_1992_I334954
from . import L3_1995_I381046
from . import L3_1997_I427107
from . import L3_2004_I652683
from . import LENA_1982_I179431
from . import MAC_1985_I202924
from . import MAC_1985_I206052
from . import MARKII_1982_I177606
from . import MARKII_1985_I207785
from . import MARKII_1985_I209198
from . import MARKII_1987_I234976
from . import MARKII_1987_I247900
from . import MARKII_1988_I246184
from . import MARKII_1988_I261194
from . import MARKII_1991_I295286
from . import MARKI_1975_I100733
from . import MARKJ_1979_I141976
from . import MD1_1994_I362599
from . import NA22_1986_I18431
from . import NMD_1974_I745
from . import OPAL_1992_I321190
from . import OPAL_1993_I342766
from . import OPAL_1993_S2692198
from . import OPAL_1994_S2927284
from . import OPAL_1997_I440103
from . import OPAL_1997_I440721
from . import OPAL_1998_I474012
from . import OPAL_1998_S3749908
from . import OPAL_1998_S3780481
from . import OPAL_2000_I474010
from . import OPAL_2000_I513476
from . import OPAL_2001_I536266
from . import OPAL_2003_I599181
from . import OPAL_2004_I631361
from . import OPAL_2004_S6132243
from . import PLUTO_1979_I142517
from . import PLUTO_1980_I154270
from . import PLUTO_1981_I165122
from . import SLD_1995_I378545
from . import TASSO_1980_I153656
from . import TASSO_1984_I194774
from . import TASSO_1984_I195333
from . import TASSO_1986_I230950
from . import TASSO_1988_I263859
from . import TASSO_1989_I266893
from . import TASSO_1989_I267755
from . import TASSO_1989_I277658
from . import TASSO_1990_S2148048
from . import TOPAZ_1993_I361661
from . import TOPAZ_1995_I381777
from . import TOPAZ_1995_I381900
from . import TPC_1985_I205868
from . import TPC_1987_I235694
from . import TPC_1988_I262143
from . import UA5_1982_S875503
from . import UA5_1987_S1640666
from . import UA5_1989_S1926373
from . import VENUS_1995_I392360
from . import VENUS_1999_I500179
from . import ZEUS_2008_I780108

==> rivet-3.1.11.tar.gz: Rivet-3.1.11/pyext/rivet/hepdatapatches/__init__.py <==
from . import ALEPH_1991_S2435284
from . import ALEPH_1996_I402895
from . import ALEPH_1996_I415745
from . import ALEPH_1996_S3486095
from . import ALICE_2019_I1735351
from . import ALICE_2021_I1898832
from . import AMY_1990_I283337
from . import AMY_1990_I295160
from . import AMY_1995_I406129
from . import ARGUS_1985_I204851
from . import ARGUS_1987_I248680
from . import ARGUS_1988_I251097
from . import ARGUS_1988_I262713
from . import ARGUS_1989_I262551
from . import ARGUS_1989_I266416
from . import ARGUS_1989_I267759
from . import ARGUS_1989_I268577
from . import ARGUS_1989_I278932
from . import ARGUS_1989_I280943
from . import ARGUS_1989_I282570
from . import ARGUS_1990_I278933
from . import ARGUS_1991_I315059
from . import ARGUS_1992_I319102
from . import ARGUS_1993_S2653028
from . import ARGUS_1993_S2789213
from . import ARGUS_1994_I354224
from . import ARGUS_1994_I372451
from . import ARGUS_1997_I420421
from . import ATLAS_2013_I1190187
from . import ATLAS_2016_I1468168
from . import ATLAS_2018_I1615866
from . import ATLAS_2018_I1622737
from . import ATLAS_2018_I1635273
from . import ATLAS_2018_I1711223
from . import ATLAS_2019_I1720438
from . import ATLAS_2019_I1734263
from . import ATLAS_2019_I1746286
from . import ATLAS_2020_I1790439
from . import ATLAS_2022_I2037744
from . import ATLAS_2022_I2077570
from . import ATLAS_2022_I2614196
from . import ATLAS_2023_I2648096
from . import BABAR_2001_I558091
from . import BABAR_2005_S6181155
from . import BABAR_2006_I731865
from . import BABAR_2007_S6895344
from . import BABAR_2016_I1391152
from . import BELLE_2001_S4598261
from . import BELLE_2007_I749358
from . import BELLE_2009_I815978
from . import BELLE_2009_I822474
from . import BELLE_2009_I823878
from . import BELLE_2016_I1389855
from . import BELLE_2021_I1917200
from . import BELLE_2023_I2624324
from . import BESIII_2015_I1391138
from . import BESII_2004_I622224
from . import CDF_1997_I440101
from . import CDF_1997_I440446
from . import CELLO_1982_I12010
from . import CELLO_1983_I191415
from . import CELLO_1989_I267081
from . import CELLO_1990_I283026
from . import CELLO_1992_I345437
from . import CLEO_1985_I205668
from . import CLEO_1984_I193577
from . import CLEO_1988_I22954
from . import CLEO_1988_I23509
from . import CLEO_1994_I358510
from . import CLEO_1994_I359316
from . import CLEO_1998_I445351
from . import CLEO_2000_I526554
from . import CLEO_2001_I552541
from . import CLEO_2004_S5809304
from . import CLEOII_1997_I439745
from . import CLEOII_1999_I504672
from . import CLEOII_1999_I478217
from . import CMD3_2016_I1385598
from . import CMS_2011_I878118
from . import CMS_2011_I883318
from . import CMS_2012_I1113442
from . import CMS_2013_I1225274
from . import CMS_2015_I1342266
from . import CMS_2016_I1487288
from . import CMS_2017_I1485195
from . import CMS_2017_I1608166
from . import CMS_2017_I1631985
from . import CMS_2019_I1697571
from . import CRYSTAL_BALL_1988_I261078
from . import CRYSTAL_BALL_1989_I263581
from . import CRYSTAL_BALL_1990_I294492
from . import CRYSTAL_BALL_1991_I297905
from . import DELPHI_1990_I297698
from . import DELPHI_1991_I301657
from . import DELPHI_1991_I324035
from . import DELPHI_1992_I334948
from . import DELPHI_1993_I356732
from . import DELPHI_1993_I360638
from . import DELPHI_1995_I377487
from . import DELPHI_1995_I382285
from . import DELPHI_1995_I394052
from . import DELPHI_1995_S3137023
from . import DELPHI_1996_S3430090
from . import DELPHI_1998_I473409
from . import DELPHI_1999_I448370
from . import DELPHI_2001_I526164
from . import DELPHI_2003_I620250
from . import DELPHI_2011_I890503
from . import DM1_1979_I132828
from . import DM2_1990_I297706
from . import E605_1991_I302822
from . import HRS_1985_I201482
from . import HRS_1986_I17781
from . import HRS_1986_I18688
from . import HRS_1986_I18502
from . import HRS_1987_I215848
from . import HRS_1988_I250824
from . import HRS_1989_I276948
from . import HRS_1990_I280958
from . import HRS_1992_I339573
from . import JADE_1984_I202785
from . import JADE_1985_I213948
from . import JADE_1990_I282847
from . import L3_1990_I298078
from . import L3_1992_I334954
from . import L3_1995_I381046
from . import L3_1997_I427107
from . import L3_1998_I447945
from . import L3_2004_I652683
from . import LENA_1982_I179431
from . import LHCB_2013_I1238809
from . import LHCB_2013_I1244315
from . import LHCB_2014_I1280929
from . import MAC_1985_I202924
from . import MAC_1985_I206052
from . import MARKII_1982_I177606
from . import MARKII_1985_I207785
from . import MARKII_1985_I209198
from . import MARKII_1987_I234976
from . import MARKII_1987_I247900
from . import MARKII_1988_I246184
from . import MARKII_1988_I261194
from . import MARKII_1991_I295286
from . import MARKIII_1987_I244856
from . import MARKI_1975_I100733
from . import MARKJ_1979_I141976
from . import MD1_1994_I362599
from . import NA22_1986_I18431
from . import NMD_1974_I745
from . import OPAL_1992_I321190
from . import OPAL_1993_I342766
from . import OPAL_1993_S2692198
from . import OPAL_1994_S2927284
from . import OPAL_1997_I440103
from . import OPAL_1997_I440721
from . import OPAL_1998_I474012
from . import OPAL_1998_S3749908
from . import OPAL_1998_S3780481
from . import OPAL_2000_I474010
from . import OPAL_2000_I513476
from . import OPAL_2001_I536266
from . import OPAL_2003_I599181
from . import OPAL_2004_I631361
from . import OPAL_2004_S6132243
from . import PLUTO_1979_I142517
from . import PLUTO_1980_I154270
from . import PLUTO_1981_I165122
from . import SLD_1995_I378545
from . import TASSO_1980_I153656
from . import TASSO_1983_I191417
from . import TASSO_1984_I194774
from . import TASSO_1984_I195333
from . import TASSO_1986_I230950
from . import TASSO_1988_I263859
from . import TASSO_1989_I266893
from . import TASSO_1989_I267755
from . import TASSO_1989_I277658
from . import TASSO_1990_S2148048
from . import TOPAZ_1993_I361661
from . import TOPAZ_1995_I381777
from . import TOPAZ_1995_I381900
from . import TPC_1985_I205868
from . import TPC_1986_I217503
from . import TPC_1987_I235694
from . import TPC_1987_I246557
from . import TPC_1988_I262143
from . import UA5_1982_S875503
from . import UA5_1987_S1640666
from . import UA5_1989_S1926373
from . import VENUS_1995_I392360
from . import VENUS_1999_I500179
from . import ZEUS_2008_I780108
